<?php

/*
 * Copyright (C) 2009 agorum Software GmbH
 *
 * This file is part of agorum core
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; version 2
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
class SoapHelper {
  
  private $wsdlPath = "/dynawebservices/wsdl/";
  
  public function __construct() {
  }

  /**
      * get the URL from the auth plugin of joogorum
      */
  public function getAgorumUrl() {
		// Get the URL of the agorum SOAP
    try {
      $plugin =& JPluginHelper::getPlugin('authentication', 'joogorum');
      
      // changed it-service Stefan Steiner
      $version = new JVersion();
	     $pluginParams = ($version->RELEASE !='1.5') ? new JRegistry( $plugin->params ) : new JParameter( $plugin->params );

      ini_set('default_socket_timeout', 30);
      ini_set('tcp_nodelay', 1);
      
      // Set the variables
      return $pluginParams->get('agorum-core-url');
    }
    catch (Exception $e) {
    }
  }
  
  /**
      * login to agorum core
      */
  public function login($userName, $passWord) {
    $wsdlUrl = $this->getAgorumUrl().$this->wsdlPath;
    $options = array("connection_timeout" => 30);
    $client = new SoapClient($wsdlUrl."StaticNgOsService", $options); 
    
    $loginRequestBean = array (
      needsConnection => false,
      serviceMethod => 'login',
      transactionId =>  '',
      wsSessionId => '',
      userName => $userName,
      passWord => $passWord);
    
    $result = $client->login($loginRequestBean); 
    if ($result->connected) {
      return $result->wsSessionId; 
    }
    else {
      return null;
    }
	}
	
  /**
      * check if the session is still valid
      */
  public function isConnected($sessionId) {
    $wsdlUrl = $this->getAgorumUrl().$this->wsdlPath;
    $client = new SoapClient($wsdlUrl."StaticNgOsService"); 
    
    $isConnectedRequestBean = array (
      'needsConnection' => true,
      'serviceMethod' => 'isConnected',
      'transactionId' =>  '',
      'wsSessionId' => $sessionId);
    
    $result = $client->isConnected($isConnectedRequestBean); 
    return $result->isConnected;
	}
	
  /**
    * get items from a given folder
    */
  public function getItems($sessionId, $folderId, $requestAttributes) {
    $wsdlUrl = $this->getAgorumUrl().$this->wsdlPath;
    $client = new SoapClient($wsdlUrl."NgOSItemsService"); 
    
    $folder = array (
      'objectId' => $folderId,
      'fullPath' => '',
      'name' => '',
      'className' => ''
    );
  
    //$requestAttributes = array ( "ID", "NAME", "ISFOLDER" );

    $getItemsRequestBean = array (
      'needsConnection' => true,
      'serviceMethod' => 'getItemsFromFolder',
      'folder' => $folder,
      'requestAttributes' => $requestAttributes, 
      'requestId' => '',
      'classNames' => array('FOLDEROBJECT'),
      'sortAttribute' => 'NAME',
      'sortClassname' => 'GLOBALOBJECT',
      'sortOrder' => 'ascending_ignorecase',
      'itemsPerRequest' => 99999,
      'startItem' => 0,
      'transactionId' =>  '',
      'wsSessionId' => $sessionId);
    
    $result = $client->getItemsFromFolder($getItemsRequestBean); 

    $getItemsRequestBean = array (
      'needsConnection' => true,
      'serviceMethod' => 'getItemsFromFolder',
      'folder' => $folder,
      'requestAttributes' => $requestAttributes, 
      'requestId' => '',
      'classNames' => array('FILEOBJECT'),
      'sortAttribute' => 'NAME',
      'sortClassname' => 'GLOBALOBJECT',
      'sortOrder' => 'ascending_ignorecase',
      'itemsPerRequest' => 99999,
      'startItem' => 0,
      'transactionId' =>  '',
      'wsSessionId' => $sessionId);

    $result2 = $client->getItemsFromFolder($getItemsRequestBean); 
    
    $itemsResponseBean = $result;
    $items = $itemsResponseBean->items;

    $itemsResponseBean2 = $result2;
    $items2 = $itemsResponseBean2->items;
    
    foreach ($items2 as $item) {
      array_push ($items, $item);
    }
    
    return $items;
	}
  
	
 /**
    * get items from fulltext search
    */
  public function search($sessionId, $folderId, $requestAttributes, $query) {
    $wsdlUrl = $this->getAgorumUrl().$this->wsdlPath;
    $client = new SoapClient($wsdlUrl."NgOSSearchService"); 

		$plugin =& JPluginHelper::getPlugin('authentication', 'joogorum');
  
  // changed it-service Stefan Steiner
  $version = new JVersion();
		$pluginParams = ($version->RELEASE !='1.5') ? new JRegistry( $plugin->params ) : new JParameter( $plugin->params );
  
    $maxsearchresult = $pluginParams->get( 'maxsearchresult' );
			
    $searchRequestBean = array (
      'needsConnection' => true,
      'serviceMethod' => 'search',
      'requestAttributes' => $requestAttributes, 
      'requestId' => '',
      'itemsPerRequest' => ($maxsearchresult+1),
      'startItem' => 0,
      'transactionId' =>  '',
      'query' => 'inpath:'.$folderId.' AND '.$query,
			   'startPath' => '/',
      'wsSessionId' => $sessionId);
    
    $result = $client->search($searchRequestBean); 
    
    $searchResponseBean = $result;
    //$items = $searchResponseBean->items;
    
    return $searchResponseBean;
	}	
	
 /**
    * build a path with the given id
    */
  public function getPath($sessionId, $name, $objectId, $startFolderId) {
    $wsdlUrl = $this->getAgorumUrl().$this->wsdlPath;
    $client = new SoapClient($wsdlUrl."NgOSItemsService"); 

		$path = $this->getPathRec($client, $sessionId, $objectId, $startFolderId, $name."|".$objectId);
		return $path;
	}		
	
	private function getPathRec($client, $sessionId, $objectId, $startFolderId, $builtPath) {
		$requestAttributes = array ( "ID", "NAME" );
		
    $object = array (
      'objectId' => $objectId,
      'fullPath' => '',
      'name' => '',
      'className' => ''
    );
		
    $gifrRequestBean = array (
      'needsConnection' => true,
      'serviceMethod' => 'getItemsFromRelation',
      'requestAttributes' => $requestAttributes, 
      'requestId' => '',
      'itemsPerRequest' => 1000,
      'startItem' => 0,
      'transactionId' => '',
			   'relationClass' => 'FolderRelationObject',
			   'listDirection' => 'leftWard',
			   'object' => $object,
      'wsSessionId' => $sessionId);
    
    $result = $client->getItemsFromRelation($gifrRequestBean); 
		$items = $result->items;	
		for ($i=0;$i<count($items);$i++) {
			$id = trim($items[$i]->attributes[0], "\"");
			$name = trim($items[$i]->attributes[1], "\"");
			if ($id == $startFolderId) {
				//we are at start folder, so we have finished...
				return JText::_( 'JOOGORUM_STARTNAME', true )."|".$id."|".$builtPath;
			}
			else {
				if ($id == "9999") {
					return null;
				}
				else {
					$path = $this->getPathRec($client, $sessionId, $id, $startFolderId, $name."|".$id."|".$builtPath);
					if ($path != null) {
						$builtPath = $path;
						break;
					}
				}
			}
		}
    
    return $builtPath;
	}
}
?>